@@ -2,8 +2,10 @@
 
 pub mod group;
 pub mod peek;
+mod spin;
 pub mod state;
 
 pub use group::*;
 pub use peek::*;
+pub use spin::spin;
 pub use state::*;
