@@ -1,4 +1,4 @@
-#[derive(Debug, Clone, Copy, PartialEq, Eq)]
+#[derive(Debug, Clone, Copy, PartialEq, Eq, PartialOrd, Ord)]
 #[atomic_macro::atomic(8)]
 pub enum MemoryState {
     Uninitialized = 0,
@@ -27,10 +27,10 @@ impl MemoryState {
 impl From<u8> for MemoryState {
     fn from(s: u8) -> Self {
         match s {
-            1 => MemoryState::Initializing,
-            2 => MemoryState::Initialized,
-            3 => MemoryState::Erasing,
-            4 => MemoryState::Peeking,
+            s if s == MemoryState::Initializing as u8 => MemoryState::Initializing,
+            s if s == MemoryState::Initialized as u8 => MemoryState::Initialized,
+            s if s == MemoryState::Erasing as u8 => MemoryState::Erasing,
+            s if s == MemoryState::Peeking as u8 => MemoryState::Peeking,
             _ => MemoryState::Uninitialized,
         }
     }
